pub struct BatchAuctionInstance<P, N = Ethereum> { /* private fields */ }Expand description
A BatchAuction instance.
Contains type-safe methods for interacting with an on-chain instance of the
BatchAuction contract located at a given address, using a given
provider P.
If the contract bytecode is available (see the sol!
documentation on how to provide it), the deploy and deploy_builder methods can
be used to deploy a new instance of the contract.
See the module-level documentation for all the available methods.
Implementations
Sourceimpl<P: Provider<N>, N: Network> BatchAuctionInstance<P, N>
Instantiation and getters/setters.
impl<P: Provider<N>, N: Network> BatchAuctionInstance<P, N>
Instantiation and getters/setters.
Sourcepub const fn new(address: Address, __provider: P) -> Self
pub const fn new(address: Address, __provider: P) -> Self
Creates a new wrapper around an on-chain BatchAuction contract instance.
See the wrapper’s documentation for more details.
Sourcepub fn set_address(&mut self, address: Address)
pub fn set_address(&mut self, address: Address)
Sets the address.
Sourceimpl<P: Clone, N> BatchAuctionInstance<&P, N>
impl<P: Clone, N> BatchAuctionInstance<&P, N>
Sourcepub fn with_cloned_provider(self) -> BatchAuctionInstance<P, N>
pub fn with_cloned_provider(self) -> BatchAuctionInstance<P, N>
Clones the provider and returns a new instance with the cloned provider.
Sourceimpl<P: Provider<N>, N: Network> BatchAuctionInstance<P, N>
Function calls.
impl<P: Provider<N>, N: Network> BatchAuctionInstance<P, N>
Function calls.
Sourcepub fn call_builder<C: SolCall>(&self, call: &C) -> SolCallBuilder<&P, C, N>
pub fn call_builder<C: SolCall>(&self, call: &C) -> SolCallBuilder<&P, C, N>
Creates a new call builder using this contract instance’s provider and address.
Note that the call can be any function call, not just those defined in this contract. Prefer using the other methods for building type-safe contract calls.
Sourcepub fn DEFAULT_ADMIN_ROLE(
&self,
) -> SolCallBuilder<&P, DEFAULT_ADMIN_ROLECall, N>
pub fn DEFAULT_ADMIN_ROLE( &self, ) -> SolCallBuilder<&P, DEFAULT_ADMIN_ROLECall, N>
Creates a new call builder for the [DEFAULT_ADMIN_ROLE] function.
Sourcepub fn OPERATOR_ROLE(&self) -> SolCallBuilder<&P, OPERATOR_ROLECall, N>
pub fn OPERATOR_ROLE(&self) -> SolCallBuilder<&P, OPERATOR_ROLECall, N>
Creates a new call builder for the [OPERATOR_ROLE] function.
Sourcepub fn batchResults(
&self,
_0: U256,
_1: U256,
) -> SolCallBuilder<&P, batchResultsCall, N>
pub fn batchResults( &self, _0: U256, _1: U256, ) -> SolCallBuilder<&P, batchResultsCall, N>
Creates a new call builder for the [batchResults] function.
Sourcepub fn clearBatch(
&self,
marketId: U256,
) -> SolCallBuilder<&P, clearBatchCall, N>
pub fn clearBatch( &self, marketId: U256, ) -> SolCallBuilder<&P, clearBatchCall, N>
Creates a new call builder for the [clearBatch] function.
Sourcepub fn getBatchResult(
&self,
marketId: U256,
batchId: U256,
) -> SolCallBuilder<&P, getBatchResultCall, N>
pub fn getBatchResult( &self, marketId: U256, batchId: U256, ) -> SolCallBuilder<&P, getBatchResultCall, N>
Creates a new call builder for the [getBatchResult] function.
Sourcepub fn getRoleAdmin(
&self,
role: FixedBytes<32>,
) -> SolCallBuilder<&P, getRoleAdminCall, N>
pub fn getRoleAdmin( &self, role: FixedBytes<32>, ) -> SolCallBuilder<&P, getRoleAdminCall, N>
Creates a new call builder for the [getRoleAdmin] function.
Sourcepub fn grantRole(
&self,
role: FixedBytes<32>,
account: Address,
) -> SolCallBuilder<&P, grantRoleCall, N>
pub fn grantRole( &self, role: FixedBytes<32>, account: Address, ) -> SolCallBuilder<&P, grantRoleCall, N>
Creates a new call builder for the [grantRole] function.
Sourcepub fn hasRole(
&self,
role: FixedBytes<32>,
account: Address,
) -> SolCallBuilder<&P, hasRoleCall, N>
pub fn hasRole( &self, role: FixedBytes<32>, account: Address, ) -> SolCallBuilder<&P, hasRoleCall, N>
Creates a new call builder for the [hasRole] function.
Sourcepub fn orderBook(&self) -> SolCallBuilder<&P, orderBookCall, N>
pub fn orderBook(&self) -> SolCallBuilder<&P, orderBookCall, N>
Creates a new call builder for the [orderBook] function.
Sourcepub fn outcomeToken(&self) -> SolCallBuilder<&P, outcomeTokenCall, N>
pub fn outcomeToken(&self) -> SolCallBuilder<&P, outcomeTokenCall, N>
Creates a new call builder for the [outcomeToken] function.
Sourcepub fn renounceRole(
&self,
role: FixedBytes<32>,
callerConfirmation: Address,
) -> SolCallBuilder<&P, renounceRoleCall, N>
pub fn renounceRole( &self, role: FixedBytes<32>, callerConfirmation: Address, ) -> SolCallBuilder<&P, renounceRoleCall, N>
Creates a new call builder for the [renounceRole] function.
Sourcepub fn revokeRole(
&self,
role: FixedBytes<32>,
account: Address,
) -> SolCallBuilder<&P, revokeRoleCall, N>
pub fn revokeRole( &self, role: FixedBytes<32>, account: Address, ) -> SolCallBuilder<&P, revokeRoleCall, N>
Creates a new call builder for the [revokeRole] function.
Sourcepub fn supportsInterface(
&self,
interfaceId: FixedBytes<4>,
) -> SolCallBuilder<&P, supportsInterfaceCall, N>
pub fn supportsInterface( &self, interfaceId: FixedBytes<4>, ) -> SolCallBuilder<&P, supportsInterfaceCall, N>
Creates a new call builder for the [supportsInterface] function.
Sourcepub fn vault(&self) -> SolCallBuilder<&P, vaultCall, N>
pub fn vault(&self) -> SolCallBuilder<&P, vaultCall, N>
Creates a new call builder for the [vault] function.
Sourceimpl<P: Provider<N>, N: Network> BatchAuctionInstance<P, N>
Event filters.
impl<P: Provider<N>, N: Network> BatchAuctionInstance<P, N>
Event filters.
Sourcepub fn event_filter<E: SolEvent>(&self) -> Event<&P, E, N>
pub fn event_filter<E: SolEvent>(&self) -> Event<&P, E, N>
Creates a new event filter using this contract instance’s provider and address.
Note that the type can be any event, not just those defined in this contract. Prefer using the other methods for building type-safe event filters.
Sourcepub fn BatchCleared_filter(&self) -> Event<&P, BatchCleared, N>
pub fn BatchCleared_filter(&self) -> Event<&P, BatchCleared, N>
Creates a new event filter for the BatchCleared event.
Sourcepub fn GtcAutoCancelled_filter(&self) -> Event<&P, GtcAutoCancelled, N>
pub fn GtcAutoCancelled_filter(&self) -> Event<&P, GtcAutoCancelled, N>
Creates a new event filter for the GtcAutoCancelled event.
Sourcepub fn OrderSettled_filter(&self) -> Event<&P, OrderSettled, N>
pub fn OrderSettled_filter(&self) -> Event<&P, OrderSettled, N>
Creates a new event filter for the OrderSettled event.
Sourcepub fn RoleAdminChanged_filter(&self) -> Event<&P, RoleAdminChanged, N>
pub fn RoleAdminChanged_filter(&self) -> Event<&P, RoleAdminChanged, N>
Creates a new event filter for the RoleAdminChanged event.
Sourcepub fn RoleGranted_filter(&self) -> Event<&P, RoleGranted, N>
pub fn RoleGranted_filter(&self) -> Event<&P, RoleGranted, N>
Creates a new event filter for the RoleGranted event.
Sourcepub fn RoleRevoked_filter(&self) -> Event<&P, RoleRevoked, N>
pub fn RoleRevoked_filter(&self) -> Event<&P, RoleRevoked, N>
Creates a new event filter for the RoleRevoked event.