pub struct FeeModelInstance<P, N = Ethereum> { /* private fields */ }Expand description
A FeeModel instance.
Contains type-safe methods for interacting with an on-chain instance of the
FeeModel contract located at a given address, using a given
provider P.
If the contract bytecode is available (see the sol!
documentation on how to provide it), the deploy and deploy_builder methods can
be used to deploy a new instance of the contract.
See the module-level documentation for all the available methods.
Implementations
Sourceimpl<P: Provider<N>, N: Network> FeeModelInstance<P, N>
Instantiation and getters/setters.
impl<P: Provider<N>, N: Network> FeeModelInstance<P, N>
Instantiation and getters/setters.
Sourcepub const fn new(address: Address, __provider: P) -> Self
pub const fn new(address: Address, __provider: P) -> Self
Creates a new wrapper around an on-chain FeeModel contract instance.
See the wrapper’s documentation for more details.
Sourcepub fn set_address(&mut self, address: Address)
pub fn set_address(&mut self, address: Address)
Sets the address.
Sourceimpl<P: Clone, N> FeeModelInstance<&P, N>
impl<P: Clone, N> FeeModelInstance<&P, N>
Sourcepub fn with_cloned_provider(self) -> FeeModelInstance<P, N>
pub fn with_cloned_provider(self) -> FeeModelInstance<P, N>
Clones the provider and returns a new instance with the cloned provider.
Sourceimpl<P: Provider<N>, N: Network> FeeModelInstance<P, N>
Function calls.
impl<P: Provider<N>, N: Network> FeeModelInstance<P, N>
Function calls.
Sourcepub fn call_builder<C: SolCall>(&self, call: &C) -> SolCallBuilder<&P, C, N>
pub fn call_builder<C: SolCall>(&self, call: &C) -> SolCallBuilder<&P, C, N>
Creates a new call builder using this contract instance’s provider and address.
Note that the call can be any function call, not just those defined in this contract. Prefer using the other methods for building type-safe contract calls.
Sourcepub fn DEFAULT_ADMIN_ROLE(
&self,
) -> SolCallBuilder<&P, DEFAULT_ADMIN_ROLECall, N>
pub fn DEFAULT_ADMIN_ROLE( &self, ) -> SolCallBuilder<&P, DEFAULT_ADMIN_ROLECall, N>
Creates a new call builder for the [DEFAULT_ADMIN_ROLE] function.
Sourcepub fn MAX_BPS(&self) -> SolCallBuilder<&P, MAX_BPSCall, N>
pub fn MAX_BPS(&self) -> SolCallBuilder<&P, MAX_BPSCall, N>
Creates a new call builder for the [MAX_BPS] function.
Sourcepub fn calculateFee(
&self,
amount: U256,
) -> SolCallBuilder<&P, calculateFeeCall, N>
pub fn calculateFee( &self, amount: U256, ) -> SolCallBuilder<&P, calculateFeeCall, N>
Creates a new call builder for the [calculateFee] function.
Sourcepub fn feeBps(&self) -> SolCallBuilder<&P, feeBpsCall, N>
pub fn feeBps(&self) -> SolCallBuilder<&P, feeBpsCall, N>
Creates a new call builder for the [feeBps] function.
Sourcepub fn getRoleAdmin(
&self,
role: FixedBytes<32>,
) -> SolCallBuilder<&P, getRoleAdminCall, N>
pub fn getRoleAdmin( &self, role: FixedBytes<32>, ) -> SolCallBuilder<&P, getRoleAdminCall, N>
Creates a new call builder for the [getRoleAdmin] function.
Sourcepub fn grantRole(
&self,
role: FixedBytes<32>,
account: Address,
) -> SolCallBuilder<&P, grantRoleCall, N>
pub fn grantRole( &self, role: FixedBytes<32>, account: Address, ) -> SolCallBuilder<&P, grantRoleCall, N>
Creates a new call builder for the [grantRole] function.
Sourcepub fn hasRole(
&self,
role: FixedBytes<32>,
account: Address,
) -> SolCallBuilder<&P, hasRoleCall, N>
pub fn hasRole( &self, role: FixedBytes<32>, account: Address, ) -> SolCallBuilder<&P, hasRoleCall, N>
Creates a new call builder for the [hasRole] function.
Sourcepub fn protocolFeeCollector(
&self,
) -> SolCallBuilder<&P, protocolFeeCollectorCall, N>
pub fn protocolFeeCollector( &self, ) -> SolCallBuilder<&P, protocolFeeCollectorCall, N>
Creates a new call builder for the [protocolFeeCollector] function.
Sourcepub fn renounceRole(
&self,
role: FixedBytes<32>,
callerConfirmation: Address,
) -> SolCallBuilder<&P, renounceRoleCall, N>
pub fn renounceRole( &self, role: FixedBytes<32>, callerConfirmation: Address, ) -> SolCallBuilder<&P, renounceRoleCall, N>
Creates a new call builder for the [renounceRole] function.
Sourcepub fn revokeRole(
&self,
role: FixedBytes<32>,
account: Address,
) -> SolCallBuilder<&P, revokeRoleCall, N>
pub fn revokeRole( &self, role: FixedBytes<32>, account: Address, ) -> SolCallBuilder<&P, revokeRoleCall, N>
Creates a new call builder for the [revokeRole] function.
Sourcepub fn setFeeBps(&self, _feeBps: U256) -> SolCallBuilder<&P, setFeeBpsCall, N>
pub fn setFeeBps(&self, _feeBps: U256) -> SolCallBuilder<&P, setFeeBpsCall, N>
Creates a new call builder for the [setFeeBps] function.
Sourcepub fn setProtocolFeeCollector(
&self,
_collector: Address,
) -> SolCallBuilder<&P, setProtocolFeeCollectorCall, N>
pub fn setProtocolFeeCollector( &self, _collector: Address, ) -> SolCallBuilder<&P, setProtocolFeeCollectorCall, N>
Creates a new call builder for the [setProtocolFeeCollector] function.
Sourcepub fn supportsInterface(
&self,
interfaceId: FixedBytes<4>,
) -> SolCallBuilder<&P, supportsInterfaceCall, N>
pub fn supportsInterface( &self, interfaceId: FixedBytes<4>, ) -> SolCallBuilder<&P, supportsInterfaceCall, N>
Creates a new call builder for the [supportsInterface] function.
Sourceimpl<P: Provider<N>, N: Network> FeeModelInstance<P, N>
Event filters.
impl<P: Provider<N>, N: Network> FeeModelInstance<P, N>
Event filters.
Sourcepub fn event_filter<E: SolEvent>(&self) -> Event<&P, E, N>
pub fn event_filter<E: SolEvent>(&self) -> Event<&P, E, N>
Creates a new event filter using this contract instance’s provider and address.
Note that the type can be any event, not just those defined in this contract. Prefer using the other methods for building type-safe event filters.
Sourcepub fn FeeBpsUpdated_filter(&self) -> Event<&P, FeeBpsUpdated, N>
pub fn FeeBpsUpdated_filter(&self) -> Event<&P, FeeBpsUpdated, N>
Creates a new event filter for the FeeBpsUpdated event.
Sourcepub fn ProtocolFeeCollectorUpdated_filter(
&self,
) -> Event<&P, ProtocolFeeCollectorUpdated, N>
pub fn ProtocolFeeCollectorUpdated_filter( &self, ) -> Event<&P, ProtocolFeeCollectorUpdated, N>
Creates a new event filter for the ProtocolFeeCollectorUpdated event.
Sourcepub fn RoleAdminChanged_filter(&self) -> Event<&P, RoleAdminChanged, N>
pub fn RoleAdminChanged_filter(&self) -> Event<&P, RoleAdminChanged, N>
Creates a new event filter for the RoleAdminChanged event.
Sourcepub fn RoleGranted_filter(&self) -> Event<&P, RoleGranted, N>
pub fn RoleGranted_filter(&self) -> Event<&P, RoleGranted, N>
Creates a new event filter for the RoleGranted event.
Sourcepub fn RoleRevoked_filter(&self) -> Event<&P, RoleRevoked, N>
pub fn RoleRevoked_filter(&self) -> Event<&P, RoleRevoked, N>
Creates a new event filter for the RoleRevoked event.