pub enum MarketFactoryEvents {
DefaultParamsUpdated(DefaultParamsUpdated),
FactoryPaused(FactoryPaused),
MarketClosed(MarketClosed),
MarketCreated(MarketCreated),
MarketStateChanged(MarketStateChanged),
RoleAdminChanged(RoleAdminChanged),
RoleGranted(RoleGranted),
RoleRevoked(RoleRevoked),
}Expand description
Container for all the MarketFactory events.
Variants
DefaultParamsUpdated(DefaultParamsUpdated)
FactoryPaused(FactoryPaused)
MarketClosed(MarketClosed)
MarketCreated(MarketCreated)
MarketStateChanged(MarketStateChanged)
RoleAdminChanged(RoleAdminChanged)
RoleGranted(RoleGranted)
RoleRevoked(RoleRevoked)
Implementations
Sourceimpl MarketFactoryEvents
impl MarketFactoryEvents
Sourcepub const SELECTORS: &'static [[u8; 32]]
pub const SELECTORS: &'static [[u8; 32]]
All the selectors of this enum.
Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.
Prefer using SolInterface methods instead.
Sourcepub const VARIANT_NAMES: &'static [&'static str]
pub const VARIANT_NAMES: &'static [&'static str]
The names of the variants in the same order as SELECTORS.
Sourcepub const SIGNATURES: &'static [&'static str]
pub const SIGNATURES: &'static [&'static str]
The signatures in the same order as SELECTORS.