pub struct MarketFactoryInstance<P, N = Ethereum> { /* private fields */ }Expand description
A MarketFactory instance.
Contains type-safe methods for interacting with an on-chain instance of the
MarketFactory contract located at a given address, using a given
provider P.
If the contract bytecode is available (see the sol!
documentation on how to provide it), the deploy and deploy_builder methods can
be used to deploy a new instance of the contract.
See the module-level documentation for all the available methods.
Implementations
Sourceimpl<P: Provider<N>, N: Network> MarketFactoryInstance<P, N>
Instantiation and getters/setters.
impl<P: Provider<N>, N: Network> MarketFactoryInstance<P, N>
Instantiation and getters/setters.
Sourcepub const fn new(address: Address, __provider: P) -> Self
pub const fn new(address: Address, __provider: P) -> Self
Creates a new wrapper around an on-chain MarketFactory contract instance.
See the wrapper’s documentation for more details.
Sourcepub fn set_address(&mut self, address: Address)
pub fn set_address(&mut self, address: Address)
Sets the address.
Sourceimpl<P: Clone, N> MarketFactoryInstance<&P, N>
impl<P: Clone, N> MarketFactoryInstance<&P, N>
Sourcepub fn with_cloned_provider(self) -> MarketFactoryInstance<P, N>
pub fn with_cloned_provider(self) -> MarketFactoryInstance<P, N>
Clones the provider and returns a new instance with the cloned provider.
Sourceimpl<P: Provider<N>, N: Network> MarketFactoryInstance<P, N>
Function calls.
impl<P: Provider<N>, N: Network> MarketFactoryInstance<P, N>
Function calls.
Sourcepub fn call_builder<C: SolCall>(&self, call: &C) -> SolCallBuilder<&P, C, N>
pub fn call_builder<C: SolCall>(&self, call: &C) -> SolCallBuilder<&P, C, N>
Creates a new call builder using this contract instance’s provider and address.
Note that the call can be any function call, not just those defined in this contract. Prefer using the other methods for building type-safe contract calls.
Sourcepub fn ADMIN_ROLE(&self) -> SolCallBuilder<&P, ADMIN_ROLECall, N>
pub fn ADMIN_ROLE(&self) -> SolCallBuilder<&P, ADMIN_ROLECall, N>
Creates a new call builder for the [ADMIN_ROLE] function.
Sourcepub fn DEFAULT_ADMIN_ROLE(
&self,
) -> SolCallBuilder<&P, DEFAULT_ADMIN_ROLECall, N>
pub fn DEFAULT_ADMIN_ROLE( &self, ) -> SolCallBuilder<&P, DEFAULT_ADMIN_ROLECall, N>
Creates a new call builder for the [DEFAULT_ADMIN_ROLE] function.
Sourcepub fn MARKET_CREATOR_ROLE(
&self,
) -> SolCallBuilder<&P, MARKET_CREATOR_ROLECall, N>
pub fn MARKET_CREATOR_ROLE( &self, ) -> SolCallBuilder<&P, MARKET_CREATOR_ROLECall, N>
Creates a new call builder for the [MARKET_CREATOR_ROLE] function.
Sourcepub fn activeMarkets(
&self,
_0: U256,
) -> SolCallBuilder<&P, activeMarketsCall, N>
pub fn activeMarkets( &self, _0: U256, ) -> SolCallBuilder<&P, activeMarketsCall, N>
Creates a new call builder for the [activeMarkets] function.
Sourcepub fn cancelMarket(
&self,
factoryMarketId: U256,
) -> SolCallBuilder<&P, cancelMarketCall, N>
pub fn cancelMarket( &self, factoryMarketId: U256, ) -> SolCallBuilder<&P, cancelMarketCall, N>
Creates a new call builder for the [cancelMarket] function.
Sourcepub fn closeMarket(
&self,
factoryMarketId: U256,
) -> SolCallBuilder<&P, closeMarketCall, N>
pub fn closeMarket( &self, factoryMarketId: U256, ) -> SolCallBuilder<&P, closeMarketCall, N>
Creates a new call builder for the [closeMarket] function.
Sourcepub fn closedMarkets(
&self,
_0: U256,
) -> SolCallBuilder<&P, closedMarketsCall, N>
pub fn closedMarkets( &self, _0: U256, ) -> SolCallBuilder<&P, closedMarketsCall, N>
Creates a new call builder for the [closedMarkets] function.
Sourcepub fn createMarket(
&self,
priceId: FixedBytes<32>,
strikePrice: i64,
duration: U256,
batchInterval: U256,
minLots: u128,
) -> SolCallBuilder<&P, createMarketCall, N>
pub fn createMarket( &self, priceId: FixedBytes<32>, strikePrice: i64, duration: U256, batchInterval: U256, minLots: u128, ) -> SolCallBuilder<&P, createMarketCall, N>
Creates a new call builder for the [createMarket] function.
Sourcepub fn defaultBatchInterval(
&self,
) -> SolCallBuilder<&P, defaultBatchIntervalCall, N>
pub fn defaultBatchInterval( &self, ) -> SolCallBuilder<&P, defaultBatchIntervalCall, N>
Creates a new call builder for the [defaultBatchInterval] function.
Sourcepub fn defaultMinLots(&self) -> SolCallBuilder<&P, defaultMinLotsCall, N>
pub fn defaultMinLots(&self) -> SolCallBuilder<&P, defaultMinLotsCall, N>
Creates a new call builder for the [defaultMinLots] function.
Sourcepub fn getActiveMarketCount(
&self,
) -> SolCallBuilder<&P, getActiveMarketCountCall, N>
pub fn getActiveMarketCount( &self, ) -> SolCallBuilder<&P, getActiveMarketCountCall, N>
Creates a new call builder for the [getActiveMarketCount] function.
Sourcepub fn getClosedMarketCount(
&self,
) -> SolCallBuilder<&P, getClosedMarketCountCall, N>
pub fn getClosedMarketCount( &self, ) -> SolCallBuilder<&P, getClosedMarketCountCall, N>
Creates a new call builder for the [getClosedMarketCount] function.
Sourcepub fn getMarketState(
&self,
factoryMarketId: U256,
) -> SolCallBuilder<&P, getMarketStateCall, N>
pub fn getMarketState( &self, factoryMarketId: U256, ) -> SolCallBuilder<&P, getMarketStateCall, N>
Creates a new call builder for the [getMarketState] function.
Sourcepub fn getResolvedMarketCount(
&self,
) -> SolCallBuilder<&P, getResolvedMarketCountCall, N>
pub fn getResolvedMarketCount( &self, ) -> SolCallBuilder<&P, getResolvedMarketCountCall, N>
Creates a new call builder for the [getResolvedMarketCount] function.
Sourcepub fn getRoleAdmin(
&self,
role: FixedBytes<32>,
) -> SolCallBuilder<&P, getRoleAdminCall, N>
pub fn getRoleAdmin( &self, role: FixedBytes<32>, ) -> SolCallBuilder<&P, getRoleAdminCall, N>
Creates a new call builder for the [getRoleAdmin] function.
Sourcepub fn grantRole(
&self,
role: FixedBytes<32>,
account: Address,
) -> SolCallBuilder<&P, grantRoleCall, N>
pub fn grantRole( &self, role: FixedBytes<32>, account: Address, ) -> SolCallBuilder<&P, grantRoleCall, N>
Creates a new call builder for the [grantRole] function.
Sourcepub fn hasRole(
&self,
role: FixedBytes<32>,
account: Address,
) -> SolCallBuilder<&P, hasRoleCall, N>
pub fn hasRole( &self, role: FixedBytes<32>, account: Address, ) -> SolCallBuilder<&P, hasRoleCall, N>
Creates a new call builder for the [hasRole] function.
Sourcepub fn marketMeta(&self, _0: U256) -> SolCallBuilder<&P, marketMetaCall, N>
pub fn marketMeta(&self, _0: U256) -> SolCallBuilder<&P, marketMetaCall, N>
Creates a new call builder for the [marketMeta] function.
Sourcepub fn nextFactoryMarketId(
&self,
) -> SolCallBuilder<&P, nextFactoryMarketIdCall, N>
pub fn nextFactoryMarketId( &self, ) -> SolCallBuilder<&P, nextFactoryMarketIdCall, N>
Creates a new call builder for the [nextFactoryMarketId] function.
Sourcepub fn orderBook(&self) -> SolCallBuilder<&P, orderBookCall, N>
pub fn orderBook(&self) -> SolCallBuilder<&P, orderBookCall, N>
Creates a new call builder for the [orderBook] function.
Sourcepub fn outcomeToken(&self) -> SolCallBuilder<&P, outcomeTokenCall, N>
pub fn outcomeToken(&self) -> SolCallBuilder<&P, outcomeTokenCall, N>
Creates a new call builder for the [outcomeToken] function.
Sourcepub fn pauseFactory(
&self,
_paused: bool,
) -> SolCallBuilder<&P, pauseFactoryCall, N>
pub fn pauseFactory( &self, _paused: bool, ) -> SolCallBuilder<&P, pauseFactoryCall, N>
Creates a new call builder for the [pauseFactory] function.
Sourcepub fn paused(&self) -> SolCallBuilder<&P, pausedCall, N>
pub fn paused(&self) -> SolCallBuilder<&P, pausedCall, N>
Creates a new call builder for the [paused] function.
Sourcepub fn renounceRole(
&self,
role: FixedBytes<32>,
callerConfirmation: Address,
) -> SolCallBuilder<&P, renounceRoleCall, N>
pub fn renounceRole( &self, role: FixedBytes<32>, callerConfirmation: Address, ) -> SolCallBuilder<&P, renounceRoleCall, N>
Creates a new call builder for the [renounceRole] function.
Sourcepub fn resolvedMarkets(
&self,
_0: U256,
) -> SolCallBuilder<&P, resolvedMarketsCall, N>
pub fn resolvedMarkets( &self, _0: U256, ) -> SolCallBuilder<&P, resolvedMarketsCall, N>
Creates a new call builder for the [resolvedMarkets] function.
Sourcepub fn revokeRole(
&self,
role: FixedBytes<32>,
account: Address,
) -> SolCallBuilder<&P, revokeRoleCall, N>
pub fn revokeRole( &self, role: FixedBytes<32>, account: Address, ) -> SolCallBuilder<&P, revokeRoleCall, N>
Creates a new call builder for the [revokeRole] function.
Sourcepub fn setDefaultParams(
&self,
_batchInterval: U256,
_minLots: u128,
) -> SolCallBuilder<&P, setDefaultParamsCall, N>
pub fn setDefaultParams( &self, _batchInterval: U256, _minLots: u128, ) -> SolCallBuilder<&P, setDefaultParamsCall, N>
Creates a new call builder for the [setDefaultParams] function.
Sourcepub fn setResolved(
&self,
factoryMarketId: U256,
outcomeYes: bool,
settlementPrice: i64,
) -> SolCallBuilder<&P, setResolvedCall, N>
pub fn setResolved( &self, factoryMarketId: U256, outcomeYes: bool, settlementPrice: i64, ) -> SolCallBuilder<&P, setResolvedCall, N>
Creates a new call builder for the [setResolved] function.
Sourcepub fn setResolving(
&self,
factoryMarketId: U256,
) -> SolCallBuilder<&P, setResolvingCall, N>
pub fn setResolving( &self, factoryMarketId: U256, ) -> SolCallBuilder<&P, setResolvingCall, N>
Creates a new call builder for the [setResolving] function.
Sourcepub fn supportsInterface(
&self,
interfaceId: FixedBytes<4>,
) -> SolCallBuilder<&P, supportsInterfaceCall, N>
pub fn supportsInterface( &self, interfaceId: FixedBytes<4>, ) -> SolCallBuilder<&P, supportsInterfaceCall, N>
Creates a new call builder for the [supportsInterface] function.
Sourceimpl<P: Provider<N>, N: Network> MarketFactoryInstance<P, N>
Event filters.
impl<P: Provider<N>, N: Network> MarketFactoryInstance<P, N>
Event filters.
Sourcepub fn event_filter<E: SolEvent>(&self) -> Event<&P, E, N>
pub fn event_filter<E: SolEvent>(&self) -> Event<&P, E, N>
Creates a new event filter using this contract instance’s provider and address.
Note that the type can be any event, not just those defined in this contract. Prefer using the other methods for building type-safe event filters.
Sourcepub fn DefaultParamsUpdated_filter(&self) -> Event<&P, DefaultParamsUpdated, N>
pub fn DefaultParamsUpdated_filter(&self) -> Event<&P, DefaultParamsUpdated, N>
Creates a new event filter for the DefaultParamsUpdated event.
Sourcepub fn FactoryPaused_filter(&self) -> Event<&P, FactoryPaused, N>
pub fn FactoryPaused_filter(&self) -> Event<&P, FactoryPaused, N>
Creates a new event filter for the FactoryPaused event.
Sourcepub fn MarketClosed_filter(&self) -> Event<&P, MarketClosed, N>
pub fn MarketClosed_filter(&self) -> Event<&P, MarketClosed, N>
Creates a new event filter for the MarketClosed event.
Sourcepub fn MarketCreated_filter(&self) -> Event<&P, MarketCreated, N>
pub fn MarketCreated_filter(&self) -> Event<&P, MarketCreated, N>
Creates a new event filter for the MarketCreated event.
Sourcepub fn MarketStateChanged_filter(&self) -> Event<&P, MarketStateChanged, N>
pub fn MarketStateChanged_filter(&self) -> Event<&P, MarketStateChanged, N>
Creates a new event filter for the MarketStateChanged event.
Sourcepub fn RoleAdminChanged_filter(&self) -> Event<&P, RoleAdminChanged, N>
pub fn RoleAdminChanged_filter(&self) -> Event<&P, RoleAdminChanged, N>
Creates a new event filter for the RoleAdminChanged event.
Sourcepub fn RoleGranted_filter(&self) -> Event<&P, RoleGranted, N>
pub fn RoleGranted_filter(&self) -> Event<&P, RoleGranted, N>
Creates a new event filter for the RoleGranted event.
Sourcepub fn RoleRevoked_filter(&self) -> Event<&P, RoleRevoked, N>
pub fn RoleRevoked_filter(&self) -> Event<&P, RoleRevoked, N>
Creates a new event filter for the RoleRevoked event.