pub struct createMarketWithPositionsCall {
pub priceId: FixedBytes<32>,
pub strikePrice: i64,
pub expiryTime: U256,
pub batchInterval: U256,
pub minLots: u128,
}Expand description
Function with signature createMarketWithPositions(bytes32,int64,uint256,uint256,uint128) and selector 0x11f3814b.
function createMarketWithPositions(bytes32 priceId, int64 strikePrice, uint256 expiryTime, uint256 batchInterval, uint128 minLots) external returns (uint256 factoryMarketId);Fields
priceId: FixedBytes<32>strikePrice: i64expiryTime: U256batchInterval: U256minLots: u128Trait Implementations
Sourceimpl Clone for createMarketWithPositionsCall
impl Clone for createMarketWithPositionsCall
Sourcefn clone(&self) -> createMarketWithPositionsCall
fn clone(&self) -> createMarketWithPositionsCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl SolCall for createMarketWithPositionsCall
impl SolCall for createMarketWithPositionsCall
Sourceconst SIGNATURE: &'static str = "createMarketWithPositions(bytes32,int64,uint256,uint256,uint128)"
const SIGNATURE: &'static str = "createMarketWithPositions(bytes32,int64,uint256,uint256,uint128)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (FixedBytes<32>, Int<64>, Uint<256>, Uint<256>, Uint<128>)
type Parameters<'a> = (FixedBytes<32>, Int<64>, Uint<256>, Uint<256>, Uint<128>)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<createMarketWithPositionsCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<createMarketWithPositionsCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype ReturnTuple<'a> = (Uint<256>,)
type ReturnTuple<'a> = (Uint<256>,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<createMarketWithPositionsCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<createMarketWithPositionsCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.