OrderBookInstance

Struct OrderBookInstance 

pub struct OrderBookInstance<P, N = Ethereum> { /* private fields */ }
A OrderBook instance.

Contains type-safe methods for interacting with an on-chain instance of the OrderBook contract located at a given address, using a given provider P.

If the contract bytecode is available (see the sol! documentation on how to provide it), the deploy and deploy_builder methods can be used to deploy a new instance of the contract.

See the module-level documentation for all the available methods.

Implementations

Source

impl<P: Provider<N>, N: Network> OrderBookInstance<P, N>

Instantiation and getters/setters.

pub const fn new(address: Address, __provider: P) -> Self

Creates a new wrapper around an on-chain OrderBook contract instance.

See the wrapper’s documentation for more details.

pub const fn address(&self) -> &Address

Returns a reference to the address.

pub fn set_address(&mut self, address: Address)

Sets the address.

pub fn at(self, address: Address) -> Self

Sets the address and returns self.

pub const fn provider(&self) -> &P

Returns a reference to the provider.

Source

impl<P: Clone, N> OrderBookInstance<&P, N>

pub fn with_cloned_provider(self) -> OrderBookInstance<P, N>

Clones the provider and returns a new instance with the cloned provider.

Source

impl<P: Provider<N>, N: Network> OrderBookInstance<P, N>

Function calls.

pub fn call_builder<C: SolCall>(&self, call: &C) -> SolCallBuilder<&P, C, N>

Creates a new call builder using this contract instance’s provider and address.

Note that the call can be any function call, not just those defined in this contract. Prefer using the other methods for building type-safe contract calls.

pub fn DEFAULT_ADMIN_ROLE( &self, ) -> SolCallBuilder<&P, DEFAULT_ADMIN_ROLECall, N>

Creates a new call builder for the [DEFAULT_ADMIN_ROLE] function.

pub fn MAX_ORDERS_PER_BATCH( &self, ) -> SolCallBuilder<&P, MAX_ORDERS_PER_BATCHCall, N>

Creates a new call builder for the [MAX_ORDERS_PER_BATCH] function.

pub fn OPERATOR_ROLE(&self) -> SolCallBuilder<&P, OPERATOR_ROLECall, N>

Creates a new call builder for the [OPERATOR_ROLE] function.

pub fn advanceBatch( &self, marketId: U256, ) -> SolCallBuilder<&P, advanceBatchCall, N>

Creates a new call builder for the [advanceBatch] function.

pub fn askVolumeAt( &self, marketId: U256, tick: U256, ) -> SolCallBuilder<&P, askVolumeAtCall, N>

Creates a new call builder for the [askVolumeAt] function.

pub fn bidVolumeAt( &self, marketId: U256, tick: U256, ) -> SolCallBuilder<&P, bidVolumeAtCall, N>

Creates a new call builder for the [bidVolumeAt] function.

pub fn cancelExpiredOrder( &self, orderId: U256, ) -> SolCallBuilder<&P, cancelExpiredOrderCall, N>

Creates a new call builder for the [cancelExpiredOrder] function.

pub fn cancelExpiredOrders( &self, orderIds: Vec<U256>, ) -> SolCallBuilder<&P, cancelExpiredOrdersCall, N>

Creates a new call builder for the [cancelExpiredOrders] function.

pub fn cancelOrder( &self, orderId: U256, ) -> SolCallBuilder<&P, cancelOrderCall, N>

Creates a new call builder for the [cancelOrder] function.

pub fn cancelOrders( &self, orderIds: Vec<U256>, ) -> SolCallBuilder<&P, cancelOrdersCall, N>

Creates a new call builder for the [cancelOrders] function.

pub fn cumulativeAskVolume( &self, marketId: U256, tick: U256, ) -> SolCallBuilder<&P, cumulativeAskVolumeCall, N>

Creates a new call builder for the [cumulativeAskVolume] function.

pub fn cumulativeBidVolume( &self, marketId: U256, tick: U256, ) -> SolCallBuilder<&P, cumulativeBidVolumeCall, N>

Creates a new call builder for the [cumulativeBidVolume] function.

pub fn deactivateMarket( &self, marketId: U256, ) -> SolCallBuilder<&P, deactivateMarketCall, N>

Creates a new call builder for the [deactivateMarket] function.

pub fn feeModel(&self) -> SolCallBuilder<&P, feeModelCall, N>

Creates a new call builder for the [feeModel] function.

pub fn findClearingTick( &self, marketId: U256, ) -> SolCallBuilder<&P, findClearingTickCall, N>

Creates a new call builder for the [findClearingTick] function.

pub fn getBatchOrderIds( &self, marketId: U256, batchId: U256, ) -> SolCallBuilder<&P, getBatchOrderIdsCall, N>

Creates a new call builder for the [getBatchOrderIds] function.

pub fn getRoleAdmin( &self, role: FixedBytes<32>, ) -> SolCallBuilder<&P, getRoleAdminCall, N>

Creates a new call builder for the [getRoleAdmin] function.

pub fn grantRole( &self, role: FixedBytes<32>, account: Address, ) -> SolCallBuilder<&P, grantRoleCall, N>

Creates a new call builder for the [grantRole] function.

pub fn haltMarket( &self, marketId: U256, ) -> SolCallBuilder<&P, haltMarketCall, N>

Creates a new call builder for the [haltMarket] function.

pub fn hasRole( &self, role: FixedBytes<32>, account: Address, ) -> SolCallBuilder<&P, hasRoleCall, N>

Creates a new call builder for the [hasRole] function.

pub fn markets(&self, _0: U256) -> SolCallBuilder<&P, marketsCall, N>

Creates a new call builder for the [markets] function.

pub fn nextMarketId(&self) -> SolCallBuilder<&P, nextMarketIdCall, N>

Creates a new call builder for the [nextMarketId] function.

pub fn nextOrderId(&self) -> SolCallBuilder<&P, nextOrderIdCall, N>

Creates a new call builder for the [nextOrderId] function.

pub fn onERC1155BatchReceived( &self, _0: Address, _1: Address, _2: Vec<U256>, _3: Vec<U256>, _4: Bytes, ) -> SolCallBuilder<&P, onERC1155BatchReceivedCall, N>

Creates a new call builder for the [onERC1155BatchReceived] function.

pub fn onERC1155Received( &self, _0: Address, _1: Address, _2: U256, _3: U256, _4: Bytes, ) -> SolCallBuilder<&P, onERC1155ReceivedCall, N>

Creates a new call builder for the [onERC1155Received] function.

pub fn orders(&self, _0: U256) -> SolCallBuilder<&P, ordersCall, N>

Creates a new call builder for the [orders] function.

pub fn outcomeToken(&self) -> SolCallBuilder<&P, outcomeTokenCall, N>

Creates a new call builder for the [outcomeToken] function.

pub fn placeOrder( &self, marketId: U256, side: <Side as SolType>::RustType, orderType: <OrderType as SolType>::RustType, tick: U256, lots: U256, ) -> SolCallBuilder<&P, placeOrderCall, N>

Creates a new call builder for the [placeOrder] function.

pub fn placeOrders( &self, marketId: U256, params: Vec<<OrderParam as SolType>::RustType>, ) -> SolCallBuilder<&P, placeOrdersCall, N>

Creates a new call builder for the [placeOrders] function.

pub fn pushBatchOrderId( &self, marketId: U256, batchId: U256, orderId: U256, ) -> SolCallBuilder<&P, pushBatchOrderIdCall, N>

Creates a new call builder for the [pushBatchOrderId] function.

pub fn reduceOrderLots( &self, orderId: U256, lotsToReduce: U256, ) -> SolCallBuilder<&P, reduceOrderLotsCall, N>

Creates a new call builder for the [reduceOrderLots] function.

pub fn registerMarket( &self, minLots: U256, batchInterval: U256, expiryTime: U256, ) -> SolCallBuilder<&P, registerMarketCall, N>

Creates a new call builder for the [registerMarket] function.

pub fn renounceRole( &self, role: FixedBytes<32>, callerConfirmation: Address, ) -> SolCallBuilder<&P, renounceRoleCall, N>

Creates a new call builder for the [renounceRole] function.

pub fn replaceOrders( &self, cancelIds: Vec<U256>, marketId: U256, params: Vec<<OrderParam as SolType>::RustType>, ) -> SolCallBuilder<&P, replaceOrdersCall, N>

Creates a new call builder for the [replaceOrders] function.

pub fn resumeMarket( &self, marketId: U256, ) -> SolCallBuilder<&P, resumeMarketCall, N>

Creates a new call builder for the [resumeMarket] function.

pub fn revokeRole( &self, role: FixedBytes<32>, account: Address, ) -> SolCallBuilder<&P, revokeRoleCall, N>

Creates a new call builder for the [revokeRole] function.

pub fn supportsInterface( &self, interfaceId: FixedBytes<4>, ) -> SolCallBuilder<&P, supportsInterfaceCall, N>

Creates a new call builder for the [supportsInterface] function.

pub fn totalAskVolume( &self, marketId: U256, ) -> SolCallBuilder<&P, totalAskVolumeCall, N>

Creates a new call builder for the [totalAskVolume] function.

pub fn totalBidVolume( &self, marketId: U256, ) -> SolCallBuilder<&P, totalBidVolumeCall, N>

Creates a new call builder for the [totalBidVolume] function.

pub fn transferEscrowTokens( &self, to: Address, tokenId: U256, amount: U256, ) -> SolCallBuilder<&P, transferEscrowTokensCall, N>

Creates a new call builder for the [transferEscrowTokens] function.

pub fn updateTreeVolume( &self, marketId: U256, side: <Side as SolType>::RustType, tick: U256, delta: I256, ) -> SolCallBuilder<&P, updateTreeVolumeCall, N>

Creates a new call builder for the [updateTreeVolume] function.

pub fn vault(&self) -> SolCallBuilder<&P, vaultCall, N>

Creates a new call builder for the [vault] function.

Source

impl<P: Provider<N>, N: Network> OrderBookInstance<P, N>

Event filters.

pub fn event_filter<E: SolEvent>(&self) -> Event<&P, E, N>

Creates a new event filter using this contract instance’s provider and address.

Note that the type can be any event, not just those defined in this contract. Prefer using the other methods for building type-safe event filters.

pub fn MarketDeactivated_filter(&self) -> Event<&P, MarketDeactivated, N>

Creates a new event filter for the MarketDeactivated event.

pub fn MarketHalted_filter(&self) -> Event<&P, MarketHalted, N>

Creates a new event filter for the MarketHalted event.

pub fn MarketRegistered_filter(&self) -> Event<&P, MarketRegistered, N>

Creates a new event filter for the MarketRegistered event.

pub fn MarketResumed_filter(&self) -> Event<&P, MarketResumed, N>

Creates a new event filter for the MarketResumed event.

pub fn OrderCancelled_filter(&self) -> Event<&P, OrderCancelled, N>

Creates a new event filter for the OrderCancelled event.

pub fn OrderPlaced_filter(&self) -> Event<&P, OrderPlaced, N>

Creates a new event filter for the OrderPlaced event.

pub fn RoleAdminChanged_filter(&self) -> Event<&P, RoleAdminChanged, N>

Creates a new event filter for the RoleAdminChanged event.

pub fn RoleGranted_filter(&self) -> Event<&P, RoleGranted, N>

Creates a new event filter for the RoleGranted event.

pub fn RoleRevoked_filter(&self) -> Event<&P, RoleRevoked, N>

Creates a new event filter for the RoleRevoked event.