pub struct replaceOrdersCall {
pub cancelIds: Vec<U256>,
pub marketId: U256,
pub params: Vec<<OrderParam as SolType>::RustType>,
}Expand description
Function with signature replaceOrders(uint256[],uint256,(uint8,uint8,uint8,uint64)[]) and selector 0x372df75a.
function replaceOrders(uint256[] memory cancelIds, uint256 marketId, OrderParam[] memory params) external returns (uint256[] memory orderIds);Fields
cancelIds: Vec<U256>marketId: U256params: Vec<<OrderParam as SolType>::RustType>Trait Implementations
Sourceimpl Clone for replaceOrdersCall
impl Clone for replaceOrdersCall
Sourcefn clone(&self) -> replaceOrdersCall
fn clone(&self) -> replaceOrdersCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl SolCall for replaceOrdersCall
impl SolCall for replaceOrdersCall
Sourceconst SIGNATURE: &'static str = "replaceOrders(uint256[],uint256,(uint8,uint8,uint8,uint64)[])"
const SIGNATURE: &'static str = "replaceOrders(uint256[],uint256,(uint8,uint8,uint8,uint64)[])"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Array<Uint<256>>, Uint<256>, Array<OrderParam>)
type Parameters<'a> = (Array<Uint<256>>, Uint<256>, Array<OrderParam>)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<replaceOrdersCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<replaceOrdersCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype ReturnTuple<'a> = (Array<Uint<256>>,)
type ReturnTuple<'a> = (Array<Uint<256>>,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<replaceOrdersCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<replaceOrdersCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.