pub struct updateTreeVolumeCall {
pub marketId: U256,
pub side: <Side as SolType>::RustType,
pub tick: U256,
pub delta: I256,
}Expand description
Function with signature updateTreeVolume(uint256,uint8,uint256,int256) and selector 0x4e9e373a.
function updateTreeVolume(uint256 marketId, Side side, uint256 tick, int256 delta) external;Fields
marketId: U256side: <Side as SolType>::RustTypetick: U256delta: I256Trait Implementations
Sourceimpl Clone for updateTreeVolumeCall
impl Clone for updateTreeVolumeCall
Sourcefn clone(&self) -> updateTreeVolumeCall
fn clone(&self) -> updateTreeVolumeCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl SolCall for updateTreeVolumeCall
impl SolCall for updateTreeVolumeCall
Sourceconst SIGNATURE: &'static str = "updateTreeVolume(uint256,uint8,uint256,int256)"
const SIGNATURE: &'static str = "updateTreeVolume(uint256,uint8,uint256,int256)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<256>, Side, Uint<256>, Int<256>)
type Parameters<'a> = (Uint<256>, Side, Uint<256>, Int<256>)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<updateTreeVolumeCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<updateTreeVolumeCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = updateTreeVolumeReturn
type Return = updateTreeVolumeReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<updateTreeVolumeCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<updateTreeVolumeCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.