pub enum OutcomeTokenCalls {
Show 23 variants
DEFAULT_ADMIN_ROLE(DEFAULT_ADMIN_ROLECall),
ESCROW_ROLE(ESCROW_ROLECall),
MINTER_ROLE(MINTER_ROLECall),
balanceOf(balanceOfCall),
balanceOfBatch(balanceOfBatchCall),
burnEscrow(burnEscrowCall),
burnPair(burnPairCall),
getRoleAdmin(getRoleAdminCall),
grantRole(grantRoleCall),
hasRole(hasRoleCall),
isApprovedForAll(isApprovedForAllCall),
mintPair(mintPairCall),
mintSingle(mintSingleCall),
noTokenId(noTokenIdCall),
redeem(redeemCall),
renounceRole(renounceRoleCall),
revokeRole(revokeRoleCall),
safeBatchTransferFrom(safeBatchTransferFromCall),
safeTransferFrom(safeTransferFromCall),
setApprovalForAll(setApprovalForAllCall),
supportsInterface(supportsInterfaceCall),
uri(uriCall),
yesTokenId(yesTokenIdCall),
}Expand description
Container for all the OutcomeToken function calls.
Variants
DEFAULT_ADMIN_ROLE(DEFAULT_ADMIN_ROLECall)
ESCROW_ROLE(ESCROW_ROLECall)
MINTER_ROLE(MINTER_ROLECall)
balanceOf(balanceOfCall)
balanceOfBatch(balanceOfBatchCall)
burnEscrow(burnEscrowCall)
burnPair(burnPairCall)
getRoleAdmin(getRoleAdminCall)
grantRole(grantRoleCall)
hasRole(hasRoleCall)
isApprovedForAll(isApprovedForAllCall)
mintPair(mintPairCall)
mintSingle(mintSingleCall)
noTokenId(noTokenIdCall)
redeem(redeemCall)
renounceRole(renounceRoleCall)
revokeRole(revokeRoleCall)
safeBatchTransferFrom(safeBatchTransferFromCall)
safeTransferFrom(safeTransferFromCall)
setApprovalForAll(setApprovalForAllCall)
supportsInterface(supportsInterfaceCall)
uri(uriCall)
yesTokenId(yesTokenIdCall)
Implementations
Sourceimpl OutcomeTokenCalls
impl OutcomeTokenCalls
Sourcepub const SELECTORS: &'static [[u8; 4]]
pub const SELECTORS: &'static [[u8; 4]]
All the selectors of this enum.
Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.
Prefer using SolInterface methods instead.
Sourcepub const VARIANT_NAMES: &'static [&'static str]
pub const VARIANT_NAMES: &'static [&'static str]
The names of the variants in the same order as SELECTORS.
Sourcepub const SIGNATURES: &'static [&'static str]
pub const SIGNATURES: &'static [&'static str]
The signatures in the same order as SELECTORS.