pub struct ERC1155InvalidArrayLength {
pub idsLength: U256,
pub valuesLength: U256,
}Expand description
Custom error with signature ERC1155InvalidArrayLength(uint256,uint256) and selector 0x5b059991.
error ERC1155InvalidArrayLength(uint256 idsLength, uint256 valuesLength);Fields
idsLength: U256valuesLength: U256Trait Implementations
Sourceimpl Clone for ERC1155InvalidArrayLength
impl Clone for ERC1155InvalidArrayLength
Sourcefn clone(&self) -> ERC1155InvalidArrayLength
fn clone(&self) -> ERC1155InvalidArrayLength
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl SolError for ERC1155InvalidArrayLength
impl SolError for ERC1155InvalidArrayLength
Sourceconst SIGNATURE: &'static str = "ERC1155InvalidArrayLength(uint256,uint256)"
const SIGNATURE: &'static str = "ERC1155InvalidArrayLength(uint256,uint256)"
The error’s ABI signature.
Sourcetype Parameters<'a> = (Uint<256>, Uint<256>)
type Parameters<'a> = (Uint<256>, Uint<256>)
The underlying tuple type which represents the error’s members. Read more
Sourcetype Token<'a> = <<ERC1155InvalidArrayLength as SolError>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<ERC1155InvalidArrayLength as SolError>::Parameters<'a> as SolType>::Token<'a>
The corresponding
TokenSeq type.Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> Self::Token<'_>
fn tokenize(&self) -> Self::Token<'_>
Convert to the token type used for EIP-712 encoding and decoding.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self>
ABI decode this error’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the error params when encoded in bytes, without the
selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this error’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this error’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the error to the given buffer without its selector.