OutcomeTokenInstance

Struct OutcomeTokenInstance 

pub struct OutcomeTokenInstance<P, N = Ethereum> { /* private fields */ }
A OutcomeToken instance.

Contains type-safe methods for interacting with an on-chain instance of the OutcomeToken contract located at a given address, using a given provider P.

If the contract bytecode is available (see the sol! documentation on how to provide it), the deploy and deploy_builder methods can be used to deploy a new instance of the contract.

See the module-level documentation for all the available methods.

Implementations

Source

impl<P: Provider<N>, N: Network> OutcomeTokenInstance<P, N>

Instantiation and getters/setters.

pub const fn new(address: Address, __provider: P) -> Self

Creates a new wrapper around an on-chain OutcomeToken contract instance.

See the wrapper’s documentation for more details.

pub const fn address(&self) -> &Address

Returns a reference to the address.

pub fn set_address(&mut self, address: Address)

Sets the address.

pub fn at(self, address: Address) -> Self

Sets the address and returns self.

pub const fn provider(&self) -> &P

Returns a reference to the provider.

Source

impl<P: Clone, N> OutcomeTokenInstance<&P, N>

pub fn with_cloned_provider(self) -> OutcomeTokenInstance<P, N>

Clones the provider and returns a new instance with the cloned provider.

Source

impl<P: Provider<N>, N: Network> OutcomeTokenInstance<P, N>

Function calls.

pub fn call_builder<C: SolCall>(&self, call: &C) -> SolCallBuilder<&P, C, N>

Creates a new call builder using this contract instance’s provider and address.

Note that the call can be any function call, not just those defined in this contract. Prefer using the other methods for building type-safe contract calls.

pub fn DEFAULT_ADMIN_ROLE( &self, ) -> SolCallBuilder<&P, DEFAULT_ADMIN_ROLECall, N>

Creates a new call builder for the [DEFAULT_ADMIN_ROLE] function.

pub fn ESCROW_ROLE(&self) -> SolCallBuilder<&P, ESCROW_ROLECall, N>

Creates a new call builder for the [ESCROW_ROLE] function.

pub fn MINTER_ROLE(&self) -> SolCallBuilder<&P, MINTER_ROLECall, N>

Creates a new call builder for the [MINTER_ROLE] function.

pub fn balanceOf( &self, account: Address, id: U256, ) -> SolCallBuilder<&P, balanceOfCall, N>

Creates a new call builder for the [balanceOf] function.

pub fn balanceOfBatch( &self, accounts: Vec<Address>, ids: Vec<U256>, ) -> SolCallBuilder<&P, balanceOfBatchCall, N>

Creates a new call builder for the [balanceOfBatch] function.

pub fn burnEscrow( &self, from: Address, tokenId: U256, amount: U256, ) -> SolCallBuilder<&P, burnEscrowCall, N>

Creates a new call builder for the [burnEscrow] function.

pub fn burnPair( &self, from: Address, marketId: U256, amount: U256, ) -> SolCallBuilder<&P, burnPairCall, N>

Creates a new call builder for the [burnPair] function.

pub fn getRoleAdmin( &self, role: FixedBytes<32>, ) -> SolCallBuilder<&P, getRoleAdminCall, N>

Creates a new call builder for the [getRoleAdmin] function.

pub fn grantRole( &self, role: FixedBytes<32>, account: Address, ) -> SolCallBuilder<&P, grantRoleCall, N>

Creates a new call builder for the [grantRole] function.

pub fn hasRole( &self, role: FixedBytes<32>, account: Address, ) -> SolCallBuilder<&P, hasRoleCall, N>

Creates a new call builder for the [hasRole] function.

pub fn isApprovedForAll( &self, account: Address, operator: Address, ) -> SolCallBuilder<&P, isApprovedForAllCall, N>

Creates a new call builder for the [isApprovedForAll] function.

pub fn mintPair( &self, to: Address, marketId: U256, amount: U256, ) -> SolCallBuilder<&P, mintPairCall, N>

Creates a new call builder for the [mintPair] function.

pub fn mintSingle( &self, to: Address, marketId: U256, amount: U256, isYes: bool, ) -> SolCallBuilder<&P, mintSingleCall, N>

Creates a new call builder for the [mintSingle] function.

pub fn noTokenId(&self, marketId: U256) -> SolCallBuilder<&P, noTokenIdCall, N>

Creates a new call builder for the [noTokenId] function.

pub fn redeem( &self, from: Address, marketId: U256, amount: U256, winningOutcome: bool, ) -> SolCallBuilder<&P, redeemCall, N>

Creates a new call builder for the [redeem] function.

pub fn renounceRole( &self, role: FixedBytes<32>, callerConfirmation: Address, ) -> SolCallBuilder<&P, renounceRoleCall, N>

Creates a new call builder for the [renounceRole] function.

pub fn revokeRole( &self, role: FixedBytes<32>, account: Address, ) -> SolCallBuilder<&P, revokeRoleCall, N>

Creates a new call builder for the [revokeRole] function.

pub fn safeBatchTransferFrom( &self, from: Address, to: Address, ids: Vec<U256>, values: Vec<U256>, data: Bytes, ) -> SolCallBuilder<&P, safeBatchTransferFromCall, N>

Creates a new call builder for the [safeBatchTransferFrom] function.

pub fn safeTransferFrom( &self, from: Address, to: Address, id: U256, value: U256, data: Bytes, ) -> SolCallBuilder<&P, safeTransferFromCall, N>

Creates a new call builder for the [safeTransferFrom] function.

pub fn setApprovalForAll( &self, operator: Address, approved: bool, ) -> SolCallBuilder<&P, setApprovalForAllCall, N>

Creates a new call builder for the [setApprovalForAll] function.

pub fn supportsInterface( &self, interfaceId: FixedBytes<4>, ) -> SolCallBuilder<&P, supportsInterfaceCall, N>

Creates a new call builder for the [supportsInterface] function.

pub fn uri(&self, _0: U256) -> SolCallBuilder<&P, uriCall, N>

Creates a new call builder for the [uri] function.

pub fn yesTokenId( &self, marketId: U256, ) -> SolCallBuilder<&P, yesTokenIdCall, N>

Creates a new call builder for the [yesTokenId] function.

Source

impl<P: Provider<N>, N: Network> OutcomeTokenInstance<P, N>

Event filters.

pub fn event_filter<E: SolEvent>(&self) -> Event<&P, E, N>

Creates a new event filter using this contract instance’s provider and address.

Note that the type can be any event, not just those defined in this contract. Prefer using the other methods for building type-safe event filters.

pub fn ApprovalForAll_filter(&self) -> Event<&P, ApprovalForAll, N>

Creates a new event filter for the ApprovalForAll event.

pub fn PairBurned_filter(&self) -> Event<&P, PairBurned, N>

Creates a new event filter for the PairBurned event.

pub fn PairMinted_filter(&self) -> Event<&P, PairMinted, N>

Creates a new event filter for the PairMinted event.

pub fn Redeemed_filter(&self) -> Event<&P, Redeemed, N>

Creates a new event filter for the Redeemed event.

pub fn RoleAdminChanged_filter(&self) -> Event<&P, RoleAdminChanged, N>

Creates a new event filter for the RoleAdminChanged event.

pub fn RoleGranted_filter(&self) -> Event<&P, RoleGranted, N>

Creates a new event filter for the RoleGranted event.

pub fn RoleRevoked_filter(&self) -> Event<&P, RoleRevoked, N>

Creates a new event filter for the RoleRevoked event.

pub fn TransferBatch_filter(&self) -> Event<&P, TransferBatch, N>

Creates a new event filter for the TransferBatch event.

pub fn TransferSingle_filter(&self) -> Event<&P, TransferSingle, N>

Creates a new event filter for the TransferSingle event.

pub fn URI_filter(&self) -> Event<&P, URI, N>

Creates a new event filter for the URI event.