VaultInstance

Struct VaultInstance 

pub struct VaultInstance<P, N = Ethereum> { /* private fields */ }
A Vault instance.

Contains type-safe methods for interacting with an on-chain instance of the Vault contract located at a given address, using a given provider P.

If the contract bytecode is available (see the sol! documentation on how to provide it), the deploy and deploy_builder methods can be used to deploy a new instance of the contract.

See the module-level documentation for all the available methods.

Implementations

Source

impl<P: Provider<N>, N: Network> VaultInstance<P, N>

Instantiation and getters/setters.

pub const fn new(address: Address, __provider: P) -> Self

Creates a new wrapper around an on-chain Vault contract instance.

See the wrapper’s documentation for more details.

pub const fn address(&self) -> &Address

Returns a reference to the address.

pub fn set_address(&mut self, address: Address)

Sets the address.

pub fn at(self, address: Address) -> Self

Sets the address and returns self.

pub const fn provider(&self) -> &P

Returns a reference to the provider.

Source

impl<P: Clone, N> VaultInstance<&P, N>

pub fn with_cloned_provider(self) -> VaultInstance<P, N>

Clones the provider and returns a new instance with the cloned provider.

Source

impl<P: Provider<N>, N: Network> VaultInstance<P, N>

Function calls.

pub fn call_builder<C: SolCall>(&self, call: &C) -> SolCallBuilder<&P, C, N>

Creates a new call builder using this contract instance’s provider and address.

Note that the call can be any function call, not just those defined in this contract. Prefer using the other methods for building type-safe contract calls.

pub fn DEFAULT_ADMIN_ROLE( &self, ) -> SolCallBuilder<&P, DEFAULT_ADMIN_ROLECall, N>

Creates a new call builder for the [DEFAULT_ADMIN_ROLE] function.

pub fn EMERGENCY_TIMELOCK( &self, ) -> SolCallBuilder<&P, EMERGENCY_TIMELOCKCall, N>

Creates a new call builder for the [EMERGENCY_TIMELOCK] function.

pub fn PROTOCOL_ROLE(&self) -> SolCallBuilder<&P, PROTOCOL_ROLECall, N>

Creates a new call builder for the [PROTOCOL_ROLE] function.

pub fn activateEmergency(&self) -> SolCallBuilder<&P, activateEmergencyCall, N>

Creates a new call builder for the [activateEmergency] function.

pub fn available(&self, user: Address) -> SolCallBuilder<&P, availableCall, N>

Creates a new call builder for the [available] function.

pub fn balance(&self, _0: Address) -> SolCallBuilder<&P, balanceCall, N>

Creates a new call builder for the [balance] function.

pub fn collateralToken(&self) -> SolCallBuilder<&P, collateralTokenCall, N>

Creates a new call builder for the [collateralToken] function.

pub fn depositFor( &self, user: Address, amount: U256, ) -> SolCallBuilder<&P, depositForCall, N>

Creates a new call builder for the [depositFor] function.

pub fn emergencyActivatedAt( &self, ) -> SolCallBuilder<&P, emergencyActivatedAtCall, N>

Creates a new call builder for the [emergencyActivatedAt] function.

pub fn emergencyDrainPool( &self, marketId: U256, recipient: Address, ) -> SolCallBuilder<&P, emergencyDrainPoolCall, N>

Creates a new call builder for the [emergencyDrainPool] function.

pub fn emergencyMode(&self) -> SolCallBuilder<&P, emergencyModeCall, N>

Creates a new call builder for the [emergencyMode] function.

pub fn emergencyWithdraw(&self) -> SolCallBuilder<&P, emergencyWithdrawCall, N>

Creates a new call builder for the [emergencyWithdraw] function.

pub fn getRoleAdmin( &self, role: FixedBytes<32>, ) -> SolCallBuilder<&P, getRoleAdminCall, N>

Creates a new call builder for the [getRoleAdmin] function.

pub fn grantRole( &self, role: FixedBytes<32>, account: Address, ) -> SolCallBuilder<&P, grantRoleCall, N>

Creates a new call builder for the [grantRole] function.

pub fn hasRole( &self, role: FixedBytes<32>, account: Address, ) -> SolCallBuilder<&P, hasRoleCall, N>

Creates a new call builder for the [hasRole] function.

pub fn lock( &self, user: Address, amount: U256, ) -> SolCallBuilder<&P, lockCall, N>

Creates a new call builder for the [lock] function.

pub fn locked(&self, _0: Address) -> SolCallBuilder<&P, lockedCall, N>

Creates a new call builder for the [locked] function.

pub fn marketPool(&self, _0: U256) -> SolCallBuilder<&P, marketPoolCall, N>

Creates a new call builder for the [marketPool] function.

pub fn redeemFromPool( &self, marketId: U256, to: Address, amount: U256, ) -> SolCallBuilder<&P, redeemFromPoolCall, N>

Creates a new call builder for the [redeemFromPool] function.

pub fn renounceRole( &self, role: FixedBytes<32>, callerConfirmation: Address, ) -> SolCallBuilder<&P, renounceRoleCall, N>

Creates a new call builder for the [renounceRole] function.

pub fn revokeRole( &self, role: FixedBytes<32>, account: Address, ) -> SolCallBuilder<&P, revokeRoleCall, N>

Creates a new call builder for the [revokeRole] function.

pub fn settleFill( &self, user: Address, marketId: U256, toPool: U256, feeCollector: Address, protocolFee: U256, unlockAmount: U256, withdrawUser: bool, ) -> SolCallBuilder<&P, settleFillCall, N>

Creates a new call builder for the [settleFill] function.

pub fn supportsInterface( &self, interfaceId: FixedBytes<4>, ) -> SolCallBuilder<&P, supportsInterfaceCall, N>

Creates a new call builder for the [supportsInterface] function.

pub fn unlock( &self, user: Address, amount: U256, ) -> SolCallBuilder<&P, unlockCall, N>

Creates a new call builder for the [unlock] function.

pub fn withdrawTo( &self, user: Address, amount: U256, ) -> SolCallBuilder<&P, withdrawToCall, N>

Creates a new call builder for the [withdrawTo] function.

Source

impl<P: Provider<N>, N: Network> VaultInstance<P, N>

Event filters.

pub fn event_filter<E: SolEvent>(&self) -> Event<&P, E, N>

Creates a new event filter using this contract instance’s provider and address.

Note that the type can be any event, not just those defined in this contract. Prefer using the other methods for building type-safe event filters.

pub fn AddedToMarketPool_filter(&self) -> Event<&P, AddedToMarketPool, N>

Creates a new event filter for the AddedToMarketPool event.

pub fn CollateralTransferred_filter( &self, ) -> Event<&P, CollateralTransferred, N>

Creates a new event filter for the CollateralTransferred event.

pub fn Deposited_filter(&self) -> Event<&P, Deposited, N>

Creates a new event filter for the Deposited event.

pub fn EmergencyModeActivated_filter( &self, ) -> Event<&P, EmergencyModeActivated, N>

Creates a new event filter for the EmergencyModeActivated event.

pub fn EmergencyPoolDrained_filter(&self) -> Event<&P, EmergencyPoolDrained, N>

Creates a new event filter for the EmergencyPoolDrained event.

pub fn EmergencyWithdrawn_filter(&self) -> Event<&P, EmergencyWithdrawn, N>

Creates a new event filter for the EmergencyWithdrawn event.

pub fn Locked_filter(&self) -> Event<&P, Locked, N>

Creates a new event filter for the Locked event.

pub fn RedeemedFromPool_filter(&self) -> Event<&P, RedeemedFromPool, N>

Creates a new event filter for the RedeemedFromPool event.

pub fn RoleAdminChanged_filter(&self) -> Event<&P, RoleAdminChanged, N>

Creates a new event filter for the RoleAdminChanged event.

pub fn RoleGranted_filter(&self) -> Event<&P, RoleGranted, N>

Creates a new event filter for the RoleGranted event.

pub fn RoleRevoked_filter(&self) -> Event<&P, RoleRevoked, N>

Creates a new event filter for the RoleRevoked event.

pub fn Unlocked_filter(&self) -> Event<&P, Unlocked, N>

Creates a new event filter for the Unlocked event.

pub fn Withdrawn_filter(&self) -> Event<&P, Withdrawn, N>

Creates a new event filter for the Withdrawn event.