pub struct settleFillCall {
pub user: Address,
pub marketId: U256,
pub toPool: U256,
pub feeCollector: Address,
pub protocolFee: U256,
pub unlockAmount: U256,
pub withdrawUser: bool,
}Expand description
Function with signature settleFill(address,uint256,uint256,address,uint256,uint256,bool) and selector 0x19806259.
function settleFill(address user, uint256 marketId, uint256 toPool, address feeCollector, uint256 protocolFee, uint256 unlockAmount, bool withdrawUser) external;Fields
user: AddressmarketId: U256toPool: U256feeCollector: AddressprotocolFee: U256unlockAmount: U256withdrawUser: boolTrait Implementations
Sourceimpl Clone for settleFillCall
impl Clone for settleFillCall
Sourcefn clone(&self) -> settleFillCall
fn clone(&self) -> settleFillCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl SolCall for settleFillCall
impl SolCall for settleFillCall
Sourceconst SIGNATURE: &'static str = "settleFill(address,uint256,uint256,address,uint256,uint256,bool)"
const SIGNATURE: &'static str = "settleFill(address,uint256,uint256,address,uint256,uint256,bool)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Address, Uint<256>, Uint<256>, Address, Uint<256>, Uint<256>, Bool)
type Parameters<'a> = (Address, Uint<256>, Uint<256>, Address, Uint<256>, Uint<256>, Bool)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<settleFillCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<settleFillCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = settleFillReturn
type Return = settleFillReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<settleFillCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<settleFillCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.