pub struct VaultInstance<P, N = Ethereum> { /* private fields */ }Expand description
A Vault instance.
Contains type-safe methods for interacting with an on-chain instance of the
Vault contract located at a given address, using a given
provider P.
If the contract bytecode is available (see the sol!
documentation on how to provide it), the deploy and deploy_builder methods can
be used to deploy a new instance of the contract.
See the module-level documentation for all the available methods.
Implementations
Sourceimpl<P: Provider<N>, N: Network> VaultInstance<P, N>
Instantiation and getters/setters.
impl<P: Provider<N>, N: Network> VaultInstance<P, N>
Instantiation and getters/setters.
Sourcepub const fn new(address: Address, __provider: P) -> Self
pub const fn new(address: Address, __provider: P) -> Self
Creates a new wrapper around an on-chain Vault contract instance.
See the wrapper’s documentation for more details.
Sourcepub fn set_address(&mut self, address: Address)
pub fn set_address(&mut self, address: Address)
Sets the address.
Sourceimpl<P: Clone, N> VaultInstance<&P, N>
impl<P: Clone, N> VaultInstance<&P, N>
Sourcepub fn with_cloned_provider(self) -> VaultInstance<P, N>
pub fn with_cloned_provider(self) -> VaultInstance<P, N>
Clones the provider and returns a new instance with the cloned provider.
Sourceimpl<P: Provider<N>, N: Network> VaultInstance<P, N>
Function calls.
impl<P: Provider<N>, N: Network> VaultInstance<P, N>
Function calls.
Sourcepub fn call_builder<C: SolCall>(&self, call: &C) -> SolCallBuilder<&P, C, N>
pub fn call_builder<C: SolCall>(&self, call: &C) -> SolCallBuilder<&P, C, N>
Creates a new call builder using this contract instance’s provider and address.
Note that the call can be any function call, not just those defined in this contract. Prefer using the other methods for building type-safe contract calls.
Sourcepub fn DEFAULT_ADMIN_ROLE(
&self,
) -> SolCallBuilder<&P, DEFAULT_ADMIN_ROLECall, N>
pub fn DEFAULT_ADMIN_ROLE( &self, ) -> SolCallBuilder<&P, DEFAULT_ADMIN_ROLECall, N>
Creates a new call builder for the [DEFAULT_ADMIN_ROLE] function.
Sourcepub fn EMERGENCY_TIMELOCK(
&self,
) -> SolCallBuilder<&P, EMERGENCY_TIMELOCKCall, N>
pub fn EMERGENCY_TIMELOCK( &self, ) -> SolCallBuilder<&P, EMERGENCY_TIMELOCKCall, N>
Creates a new call builder for the [EMERGENCY_TIMELOCK] function.
Sourcepub fn PROTOCOL_ROLE(&self) -> SolCallBuilder<&P, PROTOCOL_ROLECall, N>
pub fn PROTOCOL_ROLE(&self) -> SolCallBuilder<&P, PROTOCOL_ROLECall, N>
Creates a new call builder for the [PROTOCOL_ROLE] function.
Sourcepub fn activateEmergency(&self) -> SolCallBuilder<&P, activateEmergencyCall, N>
pub fn activateEmergency(&self) -> SolCallBuilder<&P, activateEmergencyCall, N>
Creates a new call builder for the [activateEmergency] function.
Sourcepub fn available(&self, user: Address) -> SolCallBuilder<&P, availableCall, N>
pub fn available(&self, user: Address) -> SolCallBuilder<&P, availableCall, N>
Creates a new call builder for the [available] function.
Sourcepub fn balance(&self, _0: Address) -> SolCallBuilder<&P, balanceCall, N>
pub fn balance(&self, _0: Address) -> SolCallBuilder<&P, balanceCall, N>
Creates a new call builder for the [balance] function.
Sourcepub fn collateralToken(&self) -> SolCallBuilder<&P, collateralTokenCall, N>
pub fn collateralToken(&self) -> SolCallBuilder<&P, collateralTokenCall, N>
Creates a new call builder for the [collateralToken] function.
Sourcepub fn depositFor(
&self,
user: Address,
amount: U256,
) -> SolCallBuilder<&P, depositForCall, N>
pub fn depositFor( &self, user: Address, amount: U256, ) -> SolCallBuilder<&P, depositForCall, N>
Creates a new call builder for the [depositFor] function.
Sourcepub fn emergencyActivatedAt(
&self,
) -> SolCallBuilder<&P, emergencyActivatedAtCall, N>
pub fn emergencyActivatedAt( &self, ) -> SolCallBuilder<&P, emergencyActivatedAtCall, N>
Creates a new call builder for the [emergencyActivatedAt] function.
Sourcepub fn emergencyDrainPool(
&self,
marketId: U256,
recipient: Address,
) -> SolCallBuilder<&P, emergencyDrainPoolCall, N>
pub fn emergencyDrainPool( &self, marketId: U256, recipient: Address, ) -> SolCallBuilder<&P, emergencyDrainPoolCall, N>
Creates a new call builder for the [emergencyDrainPool] function.
Sourcepub fn emergencyMode(&self) -> SolCallBuilder<&P, emergencyModeCall, N>
pub fn emergencyMode(&self) -> SolCallBuilder<&P, emergencyModeCall, N>
Creates a new call builder for the [emergencyMode] function.
Sourcepub fn emergencyWithdraw(&self) -> SolCallBuilder<&P, emergencyWithdrawCall, N>
pub fn emergencyWithdraw(&self) -> SolCallBuilder<&P, emergencyWithdrawCall, N>
Creates a new call builder for the [emergencyWithdraw] function.
Sourcepub fn getRoleAdmin(
&self,
role: FixedBytes<32>,
) -> SolCallBuilder<&P, getRoleAdminCall, N>
pub fn getRoleAdmin( &self, role: FixedBytes<32>, ) -> SolCallBuilder<&P, getRoleAdminCall, N>
Creates a new call builder for the [getRoleAdmin] function.
Sourcepub fn grantRole(
&self,
role: FixedBytes<32>,
account: Address,
) -> SolCallBuilder<&P, grantRoleCall, N>
pub fn grantRole( &self, role: FixedBytes<32>, account: Address, ) -> SolCallBuilder<&P, grantRoleCall, N>
Creates a new call builder for the [grantRole] function.
Sourcepub fn hasRole(
&self,
role: FixedBytes<32>,
account: Address,
) -> SolCallBuilder<&P, hasRoleCall, N>
pub fn hasRole( &self, role: FixedBytes<32>, account: Address, ) -> SolCallBuilder<&P, hasRoleCall, N>
Creates a new call builder for the [hasRole] function.
Sourcepub fn lock(
&self,
user: Address,
amount: U256,
) -> SolCallBuilder<&P, lockCall, N>
pub fn lock( &self, user: Address, amount: U256, ) -> SolCallBuilder<&P, lockCall, N>
Creates a new call builder for the [lock] function.
Sourcepub fn locked(&self, _0: Address) -> SolCallBuilder<&P, lockedCall, N>
pub fn locked(&self, _0: Address) -> SolCallBuilder<&P, lockedCall, N>
Creates a new call builder for the [locked] function.
Sourcepub fn marketPool(&self, _0: U256) -> SolCallBuilder<&P, marketPoolCall, N>
pub fn marketPool(&self, _0: U256) -> SolCallBuilder<&P, marketPoolCall, N>
Creates a new call builder for the [marketPool] function.
Sourcepub fn redeemFromPool(
&self,
marketId: U256,
to: Address,
amount: U256,
) -> SolCallBuilder<&P, redeemFromPoolCall, N>
pub fn redeemFromPool( &self, marketId: U256, to: Address, amount: U256, ) -> SolCallBuilder<&P, redeemFromPoolCall, N>
Creates a new call builder for the [redeemFromPool] function.
Sourcepub fn renounceRole(
&self,
role: FixedBytes<32>,
callerConfirmation: Address,
) -> SolCallBuilder<&P, renounceRoleCall, N>
pub fn renounceRole( &self, role: FixedBytes<32>, callerConfirmation: Address, ) -> SolCallBuilder<&P, renounceRoleCall, N>
Creates a new call builder for the [renounceRole] function.
Sourcepub fn revokeRole(
&self,
role: FixedBytes<32>,
account: Address,
) -> SolCallBuilder<&P, revokeRoleCall, N>
pub fn revokeRole( &self, role: FixedBytes<32>, account: Address, ) -> SolCallBuilder<&P, revokeRoleCall, N>
Creates a new call builder for the [revokeRole] function.
Sourcepub fn settleFill(
&self,
user: Address,
marketId: U256,
toPool: U256,
feeCollector: Address,
protocolFee: U256,
unlockAmount: U256,
withdrawUser: bool,
) -> SolCallBuilder<&P, settleFillCall, N>
pub fn settleFill( &self, user: Address, marketId: U256, toPool: U256, feeCollector: Address, protocolFee: U256, unlockAmount: U256, withdrawUser: bool, ) -> SolCallBuilder<&P, settleFillCall, N>
Creates a new call builder for the [settleFill] function.
Sourcepub fn supportsInterface(
&self,
interfaceId: FixedBytes<4>,
) -> SolCallBuilder<&P, supportsInterfaceCall, N>
pub fn supportsInterface( &self, interfaceId: FixedBytes<4>, ) -> SolCallBuilder<&P, supportsInterfaceCall, N>
Creates a new call builder for the [supportsInterface] function.
Sourcepub fn unlock(
&self,
user: Address,
amount: U256,
) -> SolCallBuilder<&P, unlockCall, N>
pub fn unlock( &self, user: Address, amount: U256, ) -> SolCallBuilder<&P, unlockCall, N>
Creates a new call builder for the [unlock] function.
Sourcepub fn withdrawTo(
&self,
user: Address,
amount: U256,
) -> SolCallBuilder<&P, withdrawToCall, N>
pub fn withdrawTo( &self, user: Address, amount: U256, ) -> SolCallBuilder<&P, withdrawToCall, N>
Creates a new call builder for the [withdrawTo] function.
Sourceimpl<P: Provider<N>, N: Network> VaultInstance<P, N>
Event filters.
impl<P: Provider<N>, N: Network> VaultInstance<P, N>
Event filters.
Sourcepub fn event_filter<E: SolEvent>(&self) -> Event<&P, E, N>
pub fn event_filter<E: SolEvent>(&self) -> Event<&P, E, N>
Creates a new event filter using this contract instance’s provider and address.
Note that the type can be any event, not just those defined in this contract. Prefer using the other methods for building type-safe event filters.
Sourcepub fn AddedToMarketPool_filter(&self) -> Event<&P, AddedToMarketPool, N>
pub fn AddedToMarketPool_filter(&self) -> Event<&P, AddedToMarketPool, N>
Creates a new event filter for the AddedToMarketPool event.
Sourcepub fn CollateralTransferred_filter(
&self,
) -> Event<&P, CollateralTransferred, N>
pub fn CollateralTransferred_filter( &self, ) -> Event<&P, CollateralTransferred, N>
Creates a new event filter for the CollateralTransferred event.
Sourcepub fn Deposited_filter(&self) -> Event<&P, Deposited, N>
pub fn Deposited_filter(&self) -> Event<&P, Deposited, N>
Creates a new event filter for the Deposited event.
Sourcepub fn EmergencyModeActivated_filter(
&self,
) -> Event<&P, EmergencyModeActivated, N>
pub fn EmergencyModeActivated_filter( &self, ) -> Event<&P, EmergencyModeActivated, N>
Creates a new event filter for the EmergencyModeActivated event.
Sourcepub fn EmergencyPoolDrained_filter(&self) -> Event<&P, EmergencyPoolDrained, N>
pub fn EmergencyPoolDrained_filter(&self) -> Event<&P, EmergencyPoolDrained, N>
Creates a new event filter for the EmergencyPoolDrained event.
Sourcepub fn EmergencyWithdrawn_filter(&self) -> Event<&P, EmergencyWithdrawn, N>
pub fn EmergencyWithdrawn_filter(&self) -> Event<&P, EmergencyWithdrawn, N>
Creates a new event filter for the EmergencyWithdrawn event.
Sourcepub fn Locked_filter(&self) -> Event<&P, Locked, N>
pub fn Locked_filter(&self) -> Event<&P, Locked, N>
Creates a new event filter for the Locked event.
Sourcepub fn RedeemedFromPool_filter(&self) -> Event<&P, RedeemedFromPool, N>
pub fn RedeemedFromPool_filter(&self) -> Event<&P, RedeemedFromPool, N>
Creates a new event filter for the RedeemedFromPool event.
Sourcepub fn RoleAdminChanged_filter(&self) -> Event<&P, RoleAdminChanged, N>
pub fn RoleAdminChanged_filter(&self) -> Event<&P, RoleAdminChanged, N>
Creates a new event filter for the RoleAdminChanged event.
Sourcepub fn RoleGranted_filter(&self) -> Event<&P, RoleGranted, N>
pub fn RoleGranted_filter(&self) -> Event<&P, RoleGranted, N>
Creates a new event filter for the RoleGranted event.
Sourcepub fn RoleRevoked_filter(&self) -> Event<&P, RoleRevoked, N>
pub fn RoleRevoked_filter(&self) -> Event<&P, RoleRevoked, N>
Creates a new event filter for the RoleRevoked event.